==> ngcp-admin-ui_13.5.1.1+0~mr13.5.1.1.tar.xz: ngcp-admin-ui-13.5.1.1+0~mr13.5.1.1/src/store/peering/getters.js <==
export function peeringPriorityOptions () {
    return [
        {
            value: '1',
            label: '1'
        },
        {
            value: '2',
            label: '2'
        },
        {
            value: '3',
            label: '3'
        },
        {
            value: '4',
            label: '4'
        },
        {
            value: '5',
            label: '5'
        },
        {
            value: '6',
            label: '6'
        },
        {
            value: '7',
            label: '7'
        },
        {
            value: '8',
            label: '8'
        },
        {
            value: '9',
            label: '9'
        }
    ]
}
export function inboundFieldList () {
    return [
        {
            value: 'from_user',
            label: 'From-User'
        },
        {
            value: 'from_domain',
            label: 'From-Domain'
        },
        {
            value: 'from_uri',
            label: 'From-URI'
        },
        {
            value: 'to_user',
            label: 'To-User'
        },
        {
            value: 'to_domain',
            label: 'To-Domain'
        },
        {
            value: 'to_uri',
            label: 'To-URI'
        },
        {
            value: 'ruri_user',
            label: 'RURI-User'
        },
        {
            value: 'ruri_domain',
            label: 'RURI-Domain'
        },
        {
            value: 'ruri_uri',
            label: 'RURI-URI'
        },
        {
            value: 'pai_user',
            label: 'PAI-User'
        },
        {
            value: 'pai_domain',
            label: 'PAI-Domain'
        },
        {
            value: 'pai_uri',
            label: 'PAI-URI'
        }
    ]
}

==> ngcp-admin-ui_14.0.1.4+0~mr14.0.1.4.tar.xz: ngcp-admin-ui-14.0.1.4+0~mr14.0.1.4/src/store/peering/getters.js <==
export function peeringPriorityOptions () {
    return [
        {
            value: 1,
            label: '1'
        },
        {
            value: 2,
            label: '2'
        },
        {
            value: 3,
            label: '3'
        },
        {
            value: 4,
            label: '4'
        },
        {
            value: 5,
            label: '5'
        },
        {
            value: 6,
            label: '6'
        },
        {
            value: 7,
            label: '7'
        },
        {
            value: 8,
            label: '8'
        },
        {
            value: 9,
            label: '9'
        }
    ]
}
export function inboundFieldList () {
    return [
        {
            value: 'from_user',
            label: 'From-User'
        },
        {
            value: 'from_domain',
            label: 'From-Domain'
        },
        {
            value: 'from_uri',
            label: 'From-URI'
        },
        {
            value: 'to_user',
            label: 'To-User'
        },
        {
            value: 'to_domain',
            label: 'To-Domain'
        },
        {
            value: 'to_uri',
            label: 'To-URI'
        },
        {
            value: 'ruri_user',
            label: 'RURI-User'
        },
        {
            value: 'ruri_domain',
            label: 'RURI-Domain'
        },
        {
            value: 'ruri_uri',
            label: 'RURI-URI'
        },
        {
            value: 'pai_user',
            label: 'PAI-User'
        },
        {
            value: 'pai_domain',
            label: 'PAI-Domain'
        },
        {
            value: 'pai_uri',
            label: 'PAI-URI'
        }
    ]
}
